#########################################################################################
#
# Ct value and viral load
#
#########################################################################################

##install.packages("readxl")
##install.packages("data.table")
##install.packages("lubridate")
##install.packages("dplyr")
##install.packages("ggplot2")
##install.packages("ggpubr")
##install.packages("scales")

# Load libraries
library(readxl)
library(data.table)
library(lubridate)
library(dplyr)
library(ggplot2)
library(ggpubr)
library(scales)

# Set the directory
path <- "C:/Users/....."
setwd(path)

# Read and format the file
df <- read_excel("dataset_Ct.xlsx")

columns <- c("COLLECT_DATA", "CITY", "MS2", "N.gene", "ORF1ab", "EPI_WEEK")
df1 <- select(df, all_of(columns))

df1$COLLECT_DATA <- as.Date(df1$COLLECT_DATA)
df1$MS2 <- as.numeric(df1$MS2)
df1$N.gene <- as.numeric(df1$N.gene)
df1$ORF1ab <- as.numeric(df1$ORF1ab)

# Keep only samples with Ct < 38 (positive)
df1 <- df1[which(df1$MS2 < 38),]
df1 <- df1[which(df1$N.gene < 38),]
df1 <- df1[which(df1$ORF1ab < 38),]

#########################################################################################
# Delimit periods with dominance (90%) by capital of a given variant
#########################################################################################

# Create vectors
capitals <- c("Belem", "Belo Horizonte", "Boa Vista", "Brasilia", "Fortaleza", "Goiania","Macapa", "Manaus", "Palmas", "Porto Velho", "Rio de Janeiro", "Sao Paulo")
delta_ini <- c('2021-08-29',	'2021-08-29',	'2021-09-12',	'2021-08-29',	'2021-08-29',	'2021-08-29',	'2021-10-10',	'2021-08-29',	'2021-08-29',	'2021-08-29',	'2021-08-29',	'2021-08-29')
delta_fim <- c('2021-12-19',	'2021-12-05',	'2021-12-12',	'2021-12-12',	'2021-11-28',	'2021-11-28',	'2021-12-19',	'2021-11-28',	'2021-12-19',	'2021-12-12',	'2021-11-21',	'2021-11-28')
omicron_ini <- c('2022-01-09',	'2021-12-26',	'2022-01-02',	'2022-01-02',	'2022-01-02',	'2021-12-26',	'2022-01-09',	'2022-01-02',	'2022-01-09',	'2022-01-02',	'2021-12-19',	'2021-12-12')
omicron_fim <- c('2022-02-27',	'2022-02-27',	'2022-02-06',	'2022-02-20',	'2022-02-27',	'2022-02-27',	'2022-02-20',	'2022-02-13',	'2022-02-27',	'2022-02-27',	'2022-02-20',	'2022-02-27')

# create empty dataframe to store data of capitals
n <- names(df1)
df_empty <- data.frame(matrix(nrow = 1, ncol = ncol(df1)))
names(df_empty) <- n
df_empty$COLLECT_DATA <- as.Date(df_empty$COLLECT_DATA)
df_empty$VOC <- NA
df.capitals <- df_empty
df.capitals <- na.omit(df.capitals)

for(i in 1:length(capitals)){ 
  df.ini <- df1[which(df1$CITY == capitals[i] & df1$COLLECT_DATA >= delta_ini[i] & df1$COLLECT_DATA <= delta_fim[i]),] %>%
    mutate(VOC = "Delta") 
  df.fim <- df1[which(df1$CITY == capitals[i] & df1$COLLECT_DATA >= omicron_ini[i] & df1$COLLECT_DATA <= omicron_fim[i]),] %>%
    mutate(VOC = "Omicron") 
  
  y <- rbind (df.ini, df.fim)
  write.csv2(y, row.names = FALSE, paste0("Ct_", capitals[i], ".csv"))
  df.capitals <- rbind(df.capitals, y)
}

write.csv2(df.capitals, row.names = FALSE, paste0("Capitals_","Ct", ".csv"))

Delta_group <- df.capitals[which(df.capitals$VOC == "Delta"),]
Omicron_group <- df.capitals[which(df.capitals$VOC == "Omicron"),]

#########################################################################################
# Perform statistic analysis and compare them with linear regression models
#########################################################################################

N.delta <- summary(df.capitals$N.gene[which(df.capitals$VOC=="Delta")])
N.omicron <- summary(df.capitals$N.gene[which(df.capitals$VOC=="Omicron")])

ORF1ab.delta <- summary(df.capitals$ORF1ab[which(df.capitals$VOC=="Delta")])
ORF1ab.omicron <- summary(df.capitals$ORF1ab[which(df.capitals$VOC=="Omicron")])

MS2.delta <- summary(df.capitals$MS2[which(df.capitals$VOC=="Delta")])
MS2.omicron <- summary(df.capitals$MS2[which(df.capitals$VOC=="Omicron")])


# Linear model for the target
m.N <- glm(formula = N.gene ~ VOC,data = df.capitals)
conf.N <- confint(m.N, level = 0.95)

m.ORF1ab <- glm(formula = ORF1ab ~ VOC,data = df.capitals)
conf.ORF <- confint(m.ORF1ab, level = 0.95)

m.MS2 <- glm(formula = MS2 ~ VOC,data = df.capitals)
conf.MS2 <- confint(m.MS2, level = 0.95)

#Teste t student
T.N <- t.test(N.gene ~ VOC, data = df.capitals, conf.level = 0.95, correct = FALSE, alternative = "two.sided")
T.ORF <- t.test(ORF1ab ~ VOC, data = df.capitals, conf.level = 0.95, correct = FALSE, alternative = "two.sided")
T.MS2 <- t.test(MS2 ~ VOC, data = df.capitals, conf.level = 0.95, correct = FALSE, alternative = "two.sided")

#########################################################################################
# Plot the violin graphic by variant
#########################################################################################

windows()

# Set colors
cores <- c('#D41159', '#5D3A9B')

#N gene
p.N <- ggplot(df.capitals, aes(x = factor(VOC), y=N.gene, fill=VOC)) +
  geom_violin(trim=FALSE) + 
  geom_boxplot(width=0.25, fill="white",lwd=0.3) +
  scale_fill_manual(values=cores)+
  theme_classic() + 
  theme(axis.text.x = element_text(size=8),
        axis.text.y = element_text(size=8),
        axis.title = element_text(size=9),
        legend.position = "none") +
  ylim(c(0,40)) +
  xlab("Lineage") + 
  ylab("Ct - N gene")
p.N

# ORF1ab
p.ORF1ab <- ggplot(df.capitals, aes(x = factor(VOC), y=ORF1ab, fill=VOC)) +
  geom_violin(trim=FALSE) + 
  geom_boxplot(width=0.25, fill="white",lwd=0.3) +
  scale_fill_manual(values=cores)+
  theme_classic() + 
  theme(axis.text.x = element_text(size=8),
        axis.text.y = element_text(size=8),
        axis.title = element_text(size=9),
        legend.position = "none") +
  ylim(c(0,40)) +
  xlab("Lineage") + 
  ylab("Ct - ORF1ab")
p.ORF1ab

# MS2 control
p.MS2 <- ggplot(df.capitals, aes(x = factor(VOC), y=MS2, fill=VOC)) +
  geom_violin(trim=FALSE) + 
  geom_boxplot(width=0.25, fill="white",lwd=0.3) +
  scale_fill_manual(values=cores)+
  theme_classic() + 
  theme(axis.text.x = element_text(size=8),
        axis.text.y = element_text(size=8),
        axis.title = element_text(size=9),
        legend.position = "none") +
  ylim(c(0,40)) +
  xlab("Lineage") + 
  ylab("Ct - MS2 control")
p.MS2

#########################################################################################
# Plot Ct distributions by epidemiological week
#########################################################################################

# N gene
N<- ggplot(df1) +
  geom_boxplot(aes(x=COLLECT_DATA,y=N.gene, group = EPI_WEEK),
               alpha=0.1,width=5,lwd=0.3) +
  theme_classic() + 
  theme(axis.text.x = element_text(size=8),
        axis.text.y = element_text(size=8),
        axis.title = element_text(size=9)) +
  scale_x_date(label = label_date("%b"),date_breaks = "1 month") +
  ylim(c(0,40)) +
  ylab("Ct - N gene") +
  xlab("Time")
N

# ORF1ab gene
ORF1ab<- ggplot(df1) +
  geom_boxplot(aes(x=COLLECT_DATA,y=ORF1ab,group = EPI_WEEK),
               alpha=0.1,width=5,lwd=0.3) +
  theme_classic() + 
  theme(axis.text.x = element_text(size=8),
        axis.text.y = element_text(size=8),
        axis.title = element_text(size=9)) +
  scale_x_date(labels = date_format("%b"),date_breaks = "1 month") +
  ylim(c(0,40)) +
  ylab("Ct - ORF1ab") +
  xlab("Time") 
ORF1ab

# MS2 control
MS2 <- ggplot(df1) +
  geom_boxplot(aes(x=COLLECT_DATA,y=MS2,group = EPI_WEEK),
               alpha=0.1,width=5,lwd=0.3) +
  theme_classic() + 
  theme(axis.text.x = element_text(size=8),
        axis.text.y = element_text(size=8),
        axis.title = element_text(size=9)) +
  scale_x_date(labels = date_format("%b"),date_breaks = "1 month") +
  ylim(c(0,40)) +
  ylab("Ct - MS2 control") +
  xlab("Time")
MS2

#  Combined plots
panel <- ggarrange(p.N,N,p.ORF1ab,ORF1ab,p.MS2,MS2,
                    labels = c("A","B","C","D","E","F"),
                    nrow = 3,ncol = 2,
                    vjust = 1.2,
                    hjust = -0.7,
                    font.label = list(size = 11))

panel


# Writes results for all models in text file 

sink("Results.txt")
"N - Delta, Omicron"
N.delta
N.omicron
T.N
"ORF1ab - Delta, Omicron"
ORF1ab.delta
ORF1ab.omicron
T.ORF
"MS2 - Delta, Omicron"
MS2.delta
MS2.omicron
T.MS2
"Regressao - Delta, Omicron"
summary(m.N)
conf.N
summary(m.ORF1ab)
conf.ORF
summary(m.MS2)
conf.MS2
sink()
